Estou usando a sdk que informei acima.

O código java que estou enviando para a API está assim

package br.com.ghnetsoft.gestorsistemas.contareceber.client.gerencianet;

import static br.com.ghnetsoft.principal.enuns.TipoPessoaEnum.JURIDICA;
import static br.com.ghnetsoft.principal.util.PrincipalUtil.retornaApenasDigitos;

import java.math.BigDecimal;
import java.util.HashMap;

import org.json.JSONObject;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import com.google.gson.GsonBuilder;

import br.com.gerencianet.gnsdk.Gerencianet;
import br.com.gerencianet.gnsdk.exceptions.GerencianetException;
import br.com.ghnetsoft.gestorsistemas.contareceber.dto.gerencianet.pagamento.envio.GerenciaNetEnviarDTO;
import br.com.ghnetsoft.gestorsistemas.contareceber.dto.gerencianet.pagamento.retorno.pix.GerenciaNetRetornoPixUnicoDTO;
import br.com.ghnetsoft.principal.exception.GeralException;
import lombok.extern.slf4j.Slf4j;

@Slf4j
@Component
public class GerenciaNetPixComponent extends GerenciaNetGeral {

    private static final long serialVersionUID = 1661011694239643947L;

    @Transactional
    public GerenciaNetRetornoPixUnicoDTO salvarPix(final GerenciaNetEnviarDTO dto) {
        try {
            log.info("gerencianet - salvarPix - dto: " + dto.toString());
            final JSONObject options = new JSONObject();
            configuracao(options);
            final HashMap<String, String> params = new HashMap<>();
            params.put("txid", " ");
            final JSONObject body = new JSONObject();
            final BigDecimal valor = somaItens(dto);
            body.put("calendario", new JSONObject().put("expiracao", 3600));
            String tipo = "cpf";
            if (JURIDICA == dto.getCliente().getTipoPessoa()) {
                tipo = "cnpj";
            }
            body.put("devedor", new JSONObject().put(tipo, retornaApenasDigitos(dto.getCliente().getDocumento())).put("nome", dto.getCliente().getNome()));
            body.put("valor", new JSONObject().put("original", valor.toString()));
            body.put("chave", dto.getCliente().getDocumento());
            body.put("solicitacaoPagador", dto.getMensagem());
            final Gerencianet gn = new Gerencianet(options);
            log.info("gerencianet - salvarPix - body: " + body.toString());
            log.info("gerencianet - salvarPix - gn: " + gn.toString());
            final JSONObject response = gn.call("pixCreateCharge", new HashMap<>(), body);
            log.info("gerencianet - response: " + response.toString());
            final GerenciaNetRetornoPixUnicoDTO dtoRetorno = new GsonBuilder().create().fromJson(response.toString(), GerenciaNetRetornoPixUnicoDTO.class);
            dtoRetorno.setRepostaCompleta(response.toString());
            log.info("gerencianet - salvarPix - retorno: " + response.toString());
            log.info("gerencianet - salvarPix - dtoRetorno: " + dtoRetorno.toString());
            return dtoRetorno;
        } catch (final GerencianetException e) {
            log.error("gerencianet - salvarPix - codigo: " + e.getCode(), e);
            log.error("gerencianet - salvarPix - erro: " + e.getError());
            log.error("gerencianet - salvarPix - erroDescricao: " + e.getErrorDescription());
            throw new GeralException(e.getErrorDescription());
        } catch (final Exception e) {
            log.error("gerencianet - salvarPix - erroDescricao: " + e.getMessage(), e);
            throw new GeralException(e.getMessage());
        }
    }
}

Que envia estas informações

body: {
    "devedor": {
        "cpf": "xxxxxxxxx",
        "nome": "Guilherme Costa Lopes"
    },
    "valor": {
        "original": "1500.00"
    },
    "chave": "xxxxxx",
    "calendario": {
        "expiracao": 3600
    },
    "solicitacaoPagador": "Conta a receber ID: b463afc1-a4e6-4c0c-8422-18c06e22f43b, com o nome: PIX"
}